@@ -1,9 +1,6 @@
-package App::pl;
+package App::pl v0.0.0;		# merge in real version when packaging for CPAN;
 
-use strict;
+use 5.16.0;
 use warnings;
-use version '5.10';
 
 warn "This is a just dummy package for CPAN.  Please run the script 'pl' directly!\n";
-
-our $VERSION = "v0.63.2";
